@@ -229,7 +229,7 @@ our %EXPORT_TAGS = ( 'all' => [ qw(
 	gluTessEndPolygon
 	gluTessNormal
 	gluTessProperty
-	gluTessVertex
+	gluTessVertex_p
 	gluUnProject
 	gluUnProject4
 ) ] );
@@ -394,7 +394,7 @@ our @EXPORT = qw(
 	GLU_V_STEP
 );
 
-our $VERSION = '0.02_01';
+our $VERSION = '0.02_02';
 
 sub AUTOLOAD {
     # This AUTOLOAD is used to 'autoload' constants from the constant()
